==> certmanager-model-v1alpha3-6.8.0-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha3/ACMEIssuerDNS01ProviderAcmeDNSFluent.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha3;

import io.fabric8.certmanager.api.model.meta.v1.SecretKeySelectorFluent;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Object;
import java.lang.String;
import io.fabric8.certmanager.api.model.meta.v1.SecretKeySelectorBuilder;
import io.fabric8.certmanager.api.model.meta.v1.SecretKeySelector;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ACMEIssuerDNS01ProviderAcmeDNSFluent<A extends ACMEIssuerDNS01ProviderAcmeDNSFluent<A>> extends BaseFluent<A>{
  public ACMEIssuerDNS01ProviderAcmeDNSFluent() {
  }
  public ACMEIssuerDNS01ProviderAcmeDNSFluent(ACMEIssuerDNS01ProviderAcmeDNS instance) {
    instance = (instance != null ? instance : new ACMEIssuerDNS01ProviderAcmeDNS());

    if (instance != null) {
      this.withAccountSecretRef(instance.getAccountSecretRef());
      this.withHost(instance.getHost());
      this.withAccountSecretRef(instance.getAccountSecretRef());
      this.withHost(instance.getHost());
    }
  }
  private SecretKeySelectorBuilder accountSecretRef;
  private String host;
  public SecretKeySelector buildAccountSecretRef() {
    return this.accountSecretRef!=null ?this.accountSecretRef.build():null;
  }
  public A withAccountSecretRef(SecretKeySelector accountSecretRef) {
    _visitables.get("accountSecretRef").remove(this.accountSecretRef);
    if (accountSecretRef!=null){ this.accountSecretRef= new SecretKeySelectorBuilder(accountSecretRef); _visitables.get("accountSecretRef").add(this.accountSecretRef);} else { this.accountSecretRef = null; _visitables.get("accountSecretRef").remove(this.accountSecretRef); } return (A) this;
  }
  public boolean hasAccountSecretRef() {
    return this.accountSecretRef != null;
  }
  public A withNewAccountSecretRef(String key,String name) {
    return (A)withAccountSecretRef(new SecretKeySelector(key, name));
  }
  public AccountSecretRefNested<A> withNewAccountSecretRef() {
    return new AccountSecretRefNested(null);
  }
  public AccountSecretRefNested<A> withNewAccountSecretRefLike(SecretKeySelector item) {
    return new AccountSecretRefNested(item);
  }
  public AccountSecretRefNested<A> editAccountSecretRef() {
    return withNewAccountSecretRefLike(java.util.Optional.ofNullable(buildAccountSecretRef()).orElse(null));
  }
  public AccountSecretRefNested<A> editOrNewAccountSecretRef() {
    return withNewAccountSecretRefLike(java.util.Optional.ofNullable(buildAccountSecretRef()).orElse(new SecretKeySelectorBuilder().build()));
  }
  public AccountSecretRefNested<A> editOrNewAccountSecretRefLike(SecretKeySelector item) {
    return withNewAccountSecretRefLike(java.util.Optional.ofNullable(buildAccountSecretRef()).orElse(item));
  }
  public String getHost() {
    return this.host;
  }
  public A withHost(String host) {
    this.host=host; return (A) this;
  }
  public boolean hasHost() {
    return this.host != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ACMEIssuerDNS01ProviderAcmeDNSFluent that = (ACMEIssuerDNS01ProviderAcmeDNSFluent) o;
    if (!java.util.Objects.equals(accountSecretRef, that.accountSecretRef)) return false;

    if (!java.util.Objects.equals(host, that.host)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(accountSecretRef,  host,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (accountSecretRef != null) { sb.append("accountSecretRef:"); sb.append(accountSecretRef + ","); }
    if (host != null) { sb.append("host:"); sb.append(host); }
    sb.append("}");
    return sb.toString();
  }
  public class AccountSecretRefNested<N> extends SecretKeySelectorFluent<AccountSecretRefNested<N>> implements Nested<N>{
    AccountSecretRefNested(SecretKeySelector item) {
      this.builder = new SecretKeySelectorBuilder(this, item);
    }
    SecretKeySelectorBuilder builder;
    public N and() {
      return (N) ACMEIssuerDNS01ProviderAcmeDNSFluent.this.withAccountSecretRef(builder.build());
    }
    public N endAccountSecretRef() {
      return and();
    }
    
  }
  
}

==> certmanager-model-v1alpha3-6.9.0-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha3/ACMEIssuerDNS01ProviderAcmeDNSFluent.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha3;

import io.fabric8.certmanager.api.model.meta.v1.SecretKeySelectorFluent;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Object;
import java.lang.String;
import io.fabric8.certmanager.api.model.meta.v1.SecretKeySelectorBuilder;
import io.fabric8.certmanager.api.model.meta.v1.SecretKeySelector;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ACMEIssuerDNS01ProviderAcmeDNSFluent<A extends ACMEIssuerDNS01ProviderAcmeDNSFluent<A>> extends BaseFluent<A>{
  public ACMEIssuerDNS01ProviderAcmeDNSFluent() {
  }
  
  public ACMEIssuerDNS01ProviderAcmeDNSFluent(ACMEIssuerDNS01ProviderAcmeDNS instance) {
    this.copyInstance(instance);
  }
  private SecretKeySelectorBuilder accountSecretRef;
  private String host;
  
  protected void copyInstance(ACMEIssuerDNS01ProviderAcmeDNS instance) {
    instance = (instance != null ? instance : new ACMEIssuerDNS01ProviderAcmeDNS());
  
    if (instance != null) {
        this.withAccountSecretRef(instance.getAccountSecretRef());
        this.withHost(instance.getHost());
        this.withAccountSecretRef(instance.getAccountSecretRef());
        this.withHost(instance.getHost());
      }
  }
  
  public SecretKeySelector buildAccountSecretRef() {
    return this.accountSecretRef!=null ?this.accountSecretRef.build():null;
  }
  
  public A withAccountSecretRef(SecretKeySelector accountSecretRef) {
    _visitables.get("accountSecretRef").remove(this.accountSecretRef);
    if (accountSecretRef!=null){ this.accountSecretRef= new SecretKeySelectorBuilder(accountSecretRef); _visitables.get("accountSecretRef").add(this.accountSecretRef);} else { this.accountSecretRef = null; _visitables.get("accountSecretRef").remove(this.accountSecretRef); } return (A) this;
  }
  
  public boolean hasAccountSecretRef() {
    return this.accountSecretRef != null;
  }
  
  public A withNewAccountSecretRef(String key,String name) {
    return (A)withAccountSecretRef(new SecretKeySelector(key, name));
  }
  
  public AccountSecretRefNested<A> withNewAccountSecretRef() {
    return new AccountSecretRefNested(null);
  }
  
  public AccountSecretRefNested<A> withNewAccountSecretRefLike(SecretKeySelector item) {
    return new AccountSecretRefNested(item);
  }
  
  public AccountSecretRefNested<A> editAccountSecretRef() {
    return withNewAccountSecretRefLike(java.util.Optional.ofNullable(buildAccountSecretRef()).orElse(null));
  }
  
  public AccountSecretRefNested<A> editOrNewAccountSecretRef() {
    return withNewAccountSecretRefLike(java.util.Optional.ofNullable(buildAccountSecretRef()).orElse(new SecretKeySelectorBuilder().build()));
  }
  
  public AccountSecretRefNested<A> editOrNewAccountSecretRefLike(SecretKeySelector item) {
    return withNewAccountSecretRefLike(java.util.Optional.ofNullable(buildAccountSecretRef()).orElse(item));
  }
  
  public String getHost() {
    return this.host;
  }
  
  public A withHost(String host) {
    this.host=host; return (A) this;
  }
  
  public boolean hasHost() {
    return this.host != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ACMEIssuerDNS01ProviderAcmeDNSFluent that = (ACMEIssuerDNS01ProviderAcmeDNSFluent) o;
    if (!java.util.Objects.equals(accountSecretRef, that.accountSecretRef)) return false;
  
    if (!java.util.Objects.equals(host, that.host)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(accountSecretRef,  host,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (accountSecretRef != null) { sb.append("accountSecretRef:"); sb.append(accountSecretRef + ","); }
    if (host != null) { sb.append("host:"); sb.append(host); }
    sb.append("}");
    return sb.toString();
  }
  public class AccountSecretRefNested<N> extends SecretKeySelectorFluent<AccountSecretRefNested<N>> implements Nested<N>{
    AccountSecretRefNested(SecretKeySelector item) {
      this.builder = new SecretKeySelectorBuilder(this, item);
    }
    SecretKeySelectorBuilder builder;
    
    public N and() {
      return (N) ACMEIssuerDNS01ProviderAcmeDNSFluent.this.withAccountSecretRef(builder.build());
    }
    
    public N endAccountSecretRef() {
      return and();
    }
    
  
  }

}
